# !/usr/bin/env python
# -*- coding: utf-8 -*-

"""
majors数据API接口 
Created on 2023/08/08
@author: majors
"""

import pandas as pd
import json
from functools import partial
import requests

server_dict = {"mjsapi":"http://mjsapi.majors.ltd:7000",
               "tsapi":"http://tsapi.majors.ltd:7000",
              "mjshis":"http://mjshis.majors.ltd:7000",
              "mjsrt":"http://mjsrt.majors.ltd:7000"}


class DataApi:

    __token = ''
    __http_url = 'http://mjsapi.majors.ltd:7000'
    __Appoint_url = ''

    def __init__(self, token='', server='', timeout=20):
        """
        Parameters
        ----------
        token: str
            API接口TOKEN，用于用户认证
        """
        if 'http' in server:
            self.__Appoint_url = server
        elif server in server_dict:
            self.__Appoint_url = server_dict[server]
        self.__token = token
        self.__timeout = timeout

    def query(self, api_name, fields='', **kwargs):
        req_params = {
            'api_name': api_name,
            'token': self.__token,
            'params': kwargs,
            'fields': fields
        }
        if self.__Appoint_url:
            res = requests.post(self.__Appoint_url, json=req_params, timeout=self.__timeout, headers={'Connection':'close'})
        else:
            if ("get_his_" in api_name) or ("get_" in api_name):
                self.__http_url = server_dict["mjshis"]
                if ("get_rt_" in api_name):
                    self.__http_url = server_dict["mjsrt"]
            else:
                self.__http_url = 'http://mjsapi.majors.ltd:7000'
            res = requests.post(self.__http_url, json=req_params, timeout=self.__timeout, headers={'Connection':'close'})
        result = json.loads(res.text)
        if result['code'] != 0:
            raise Exception(result['msg'])
        data = result['data']
        columns = data['fields']
        items = data['items']
        if columns:
            return pd.DataFrame(items, columns=columns)
        else:
            return data['items']

    def __getattr__(self, name):
        return partial(self.query, name)



# -*- coding:utf-8 -*- 
"""
majors数据API接口 
Created on 2023/08/08
@author: majors
"""

import os
import requests
import threading


TOKEN_FILE = 'majorshare_token.txt'


def set_token(token):
    user_home = os.path.expanduser('~')
    fp = os.path.join(user_home, TOKEN_FILE)
    with open(fp, 'w') as file:
        file.write(token)
    print("token文件已存储至 ",fp)
    
def get_token():
    user_home = os.path.expanduser('~')
    fp = os.path.join(user_home, TOKEN_FILE)
    try:
        with open(fp, 'r') as file:
            return file.read().strip()
    except FileNotFoundError:
        print(f"默认路径 {fp} 未发现token文件，如不小心清除，请使用set_token(token)重新设置")
        return None
    
def update_server_dict(server_dcit):
    def update(server_dcit):
        url = "http://mjsapi.majors.ltd:7000/get_server_dict"
        try:
            response = requests.get(url)
            if response.status_code == 200:
                data = response.json()  # 将响应的 JSON 数据转换为字典
                if len(data)>=4:
                    server_dcit.update(data)
            else:
                pass
        except Exception as e:
            pass
        
    thread = threading.Thread(target=update,args=(server_dcit,))
    thread.start()
    thread.join(5)  # 等待线程结束，超时时间为 5 秒
    if thread.is_alive():
         return False
         thread.terminate()  
    return True


# -*- coding:utf-8 -*- 
import os

__version__ = '1.0.0'
__author__ = 'majorshare'


from majorshare.http_client import server_dict
from majorshare.upass import get_token, set_token,update_server_dict
update_server_dict(server_dict)

from majorshare.data_proxy import pro_api,pro_bar,get_yfinance_proxy

